==> mx-service-manager_24.3.tar.xz: BUILD/translations/mx-service-manager_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>MX Service Manager</source>
        <translation>Gestionnaire de services MX - MX Service Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>&amp;Enable at boot</source>
        <translation>A&amp;ctiver au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>À &amp;propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Display help </source>
        <translation>Afficher l’aide </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>&amp;Help</source>
        <translation>A&amp;ide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Close</source>
        <translation>Q&amp;uitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Services enabled at boot</source>
        <translation>Services activés au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Services disabled at boot</source>
        <translation>Services désactivés au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>&amp;Stop</source>
        <translation>&amp;Arrêter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Cet outil dresse la liste des services et des daemons (processus qui s’exécutent en arrière-plan) présents sur ce système. Veillez à ne pas arrêter un service qui pourrait perturber un composant critique&#xa0;; il est préférable de ne pas intervenir si vous ne savez pas de quoi il s’agit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>All services</source>
        <translation>Tous les services</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Running services</source>
        <translation>Services en cours d’exécution</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Loading...</source>
        <translation>Chargement...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Impossible de déterminer le système d’initialisation. Ce programme est censé fonctionner avec systemd ou sysvinit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>S&amp;tart</source>
        <translation>Dé&amp;marrer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Désactiver au démarrage</translation>
    </message>
    <message>
        <source>%1 total services, %2 currently %3running%4</source>
        <translation type="vanished">%1 services au total, dont %2 %3en cours d’exécution%4.</translation>
    </message>
    <message>
        <source>%1 %2enabled%3 at boot, but not running</source>
        <translation type="vanished">%1 %2activés%3 au démarrage mais pas en cours d’exécution.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Version&#xa0;: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Service and daemon manager</source>
        <translation>Gestionnaire de services et de daemons</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Could not enable %1</source>
        <translation>Impossible d’activer %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 a été activé au moment du démarrage.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Could not disable %1</source>
        <translation>Impossible de désactiver %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>%1 was disabled.</source>
        <translation>%1 a été désactivé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not start %1</source>
        <translation>Impossible de démarrer %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>%1 was started.</source>
        <translation>%1 a été lancé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not stop %1</source>
        <translation>Impossible d’arrêter %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>%1 was stopped.</source>
        <translation>%1 a été arrêté.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>Q&amp;uitter</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Il semble que vous soyez connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur normal pour utiliser ce programme.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Vous devez exécuter ce programme avec un accès administrateur.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="116"/>
        <source>Could not find service description</source>
        <translation>Impossible de trouver la description du service</translation>
    </message>
</context>
</TS>

==> mx-service-manager_24.3.02.tar.xz: BUILD/translations/mx-service-manager_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <location filename="../ui_mainwindow.h" line="225"/>
        <source>MX Service Manager</source>
        <translation>Gestionnaire de services MX - MX Service Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../ui_mainwindow.h" line="226"/>
        <source>&amp;Enable at boot</source>
        <translation>A&amp;ctiver au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <location filename="../ui_mainwindow.h" line="228"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <location filename="../ui_mainwindow.h" line="230"/>
        <source>&amp;About...</source>
        <translation>À &amp;propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <location filename="../ui_mainwindow.h" line="232"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <location filename="../ui_mainwindow.h" line="236"/>
        <source>Display help </source>
        <translation>Afficher l’aide </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <location filename="../ui_mainwindow.h" line="238"/>
        <source>&amp;Help</source>
        <translation>A&amp;ide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../ui_mainwindow.h" line="240"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <location filename="../ui_mainwindow.h" line="243"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <location filename="../ui_mainwindow.h" line="245"/>
        <source>&amp;Close</source>
        <translation>Q&amp;uitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <location filename="../ui_mainwindow.h" line="247"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../ui_mainwindow.h" line="250"/>
        <source>&amp;Stop</source>
        <translation>&amp;Arrêter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../ui_mainwindow.h" line="251"/>
        <source>All services</source>
        <translation>Tous les services</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../ui_mainwindow.h" line="252"/>
        <source>Running services</source>
        <translation>Services en cours d’exécution</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../ui_mainwindow.h" line="253"/>
        <source>Services enabled at boot</source>
        <translation>Services activés au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="279"/>
        <location filename="../ui_mainwindow.h" line="254"/>
        <source>Services disabled at boot</source>
        <translation>Services désactivés au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <location filename="../ui_mainwindow.h" line="257"/>
        <source>search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <location filename="../ui_mainwindow.h" line="258"/>
        <source>Loading...</source>
        <translation>Chargement...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <location filename="../ui_mainwindow.h" line="259"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Cet outil dresse la liste des services et des daemons (processus qui s’exécutent en arrière-plan) présents sur ce système. Veillez à ne pas arrêter un service qui pourrait perturber un composant critique&#xa0;; il est préférable de ne pas intervenir si vous ne savez pas de quoi il s’agit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Impossible de déterminer le système d’initialisation. Ce programme est censé fonctionner avec systemd ou sysvinit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>S&amp;tart</source>
        <translation>Dé&amp;marrer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Désactiver au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Version&#xa0;: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Service and daemon manager</source>
        <translation>Gestionnaire de services et de daemons</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Could not enable %1</source>
        <translation>Impossible d’activer %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 a été activé au moment du démarrage.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Could not disable %1</source>
        <translation>Impossible de désactiver %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>%1 was disabled.</source>
        <translation>%1 a été désactivé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not start %1</source>
        <translation>Impossible de démarrer %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>%1 was started.</source>
        <translation>%1 a été lancé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not stop %1</source>
        <translation>Impossible d’arrêter %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>%1 was stopped.</source>
        <translation>%1 a été arrêté.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>Q&amp;uitter</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Il semble que vous soyez connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur normal pour utiliser ce programme.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Vous devez exécuter ce programme avec un accès administrateur.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="116"/>
        <source>Could not find service description</source>
        <translation>Impossible de trouver la description du service</translation>
    </message>
</context>
</TS>
